<?php
/**
 * Painting Company Theme Customizer
 *
 * @package Painting Company
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function painting_company_customize_register( $wp_customize ) {

	function painting_company_sanitize_dropdown_pages( $page_id, $setting ) {
  		$page_id = absint( $page_id );
  		return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	wp_enqueue_style('painting-company-customize-controls', trailingslashit(esc_url(get_template_directory_uri())).'/css/customize-controls.css');

	//Logo
    $wp_customize->add_setting('painting_company_logo_width', array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'painting_company_sanitize_integer'
    ));
    $wp_customize->add_control(new Painting_Company_Slider_Custom_Control($wp_customize, 'painting_company_logo_width', array(
    	'label'          => __( 'Logo Width', 'painting-company'),
        'section' => 'title_tagline',
        'settings' => 'painting_company_logo_width',
        'input_attrs' => array(
            'step' => 1,
            'min' => 0,
            'max' => 150,
        ),
    )));

	// color site title
	$wp_customize->add_setting('painting_company_sitetitle_color',array(
		'default' => '',
		'sanitize_callback' => 'painting_company_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'painting_company_sitetitle_color', array(
	   'settings' => 'painting_company_sitetitle_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Title Color', 'painting-company'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('painting_company_title_enable',array(
		'default' => true,
		'sanitize_callback' => 'painting_company_sanitize_checkbox',
	));
	$wp_customize->add_control( 'painting_company_title_enable', array(
	   'settings' => 'painting_company_title_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Title','painting-company'),
	   'type'      => 'checkbox'
	));

	// color site tagline
	$wp_customize->add_setting('painting_company_sitetagline_color',array(
		'default' => '',
		'sanitize_callback' => 'painting_company_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'painting_company_sitetagline_color', array(
	   'settings' => 'painting_company_sitetagline_color',
	   'section'   => 'title_tagline',
	   'label' => __('Site Tagline Color', 'painting-company'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('painting_company_tagline_enable',array(
		'default' => false,
		'sanitize_callback' => 'painting_company_sanitize_checkbox',
	));
	$wp_customize->add_control( 'painting_company_tagline_enable', array(
	   'settings' => 'painting_company_tagline_enable',
	   'section'   => 'title_tagline',
	   'label'     => __('Enable Site Tagline','painting-company'),
	   'type'      => 'checkbox'
	));

	// woocommerce section
	$wp_customize->add_section('painting_company_woocommerce_page_settings', array(
		'title'    => __('WooCommerce Page Settings', 'painting-company'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

	$wp_customize->add_setting('painting_company_shop_page_sidebar',array(
		'default' => false,
		'sanitize_callback'	=> 'painting_company_sanitize_checkbox'
	 ));
	 $wp_customize->add_control('painting_company_shop_page_sidebar',array(
		'type' => 'checkbox',
		'label' => __(' Check To Enable Shop page sidebar','painting-company'),
		'section' => 'painting_company_woocommerce_page_settings',
	 ));

    // shop page sidebar alignment
    $wp_customize->add_setting('painting_company_shop_page_sidebar_position', array(
		'default'           => 'Right Sidebar',
		'sanitize_callback' => 'painting_company_sanitize_choices',
	));
	$wp_customize->add_control('painting_company_shop_page_sidebar_position',array(
		'type'           => 'radio',
		'label'          => __('Shop Page Sidebar', 'painting-company'),
		'section'        => 'painting_company_woocommerce_page_settings',
		'choices'        => array(
			'Left Sidebar'  => __('Left Sidebar', 'painting-company'),
			'Right Sidebar' => __('Right Sidebar', 'painting-company'),
		),
	));	 

	$wp_customize->add_setting('painting_company_wooproducts_nav',array(
		'default' => 'Yes',
		'sanitize_callback'	=> 'painting_company_sanitize_choices'
	 ));
	 $wp_customize->add_control('painting_company_wooproducts_nav',array(
		'type' => 'select',
		'label' => __('Shop Page Products Navigation','painting-company'),
		'choices' => array(
			 'Yes' => __('Yes','painting-company'),
			 'No' => __('No','painting-company'),
		 ),
		'section' => 'painting_company_woocommerce_page_settings',
	 ));

	 $wp_customize->add_setting( 'painting_company_single_page_sidebar',array(
		'default' => false,
		'sanitize_callback'	=> 'painting_company_sanitize_checkbox'
    ) );
    $wp_customize->add_control('painting_company_single_page_sidebar',array(
    	'type' => 'checkbox',
       	'label' => __('Check To Enable Single Product Page Sidebar','painting-company'),
		'section' => 'painting_company_woocommerce_page_settings'
    ));

	// single product page sidebar alignment
    $wp_customize->add_setting('painting_company_single_product_page_layout', array(
		'default'           => 'Right Sidebar',
		'sanitize_callback' => 'painting_company_sanitize_choices',
	));
	$wp_customize->add_control('painting_company_single_product_page_layout',array(
		'type'           => 'radio',
		'label'          => __('Single product Page Sidebar', 'painting-company'),
		'section'        => 'painting_company_woocommerce_page_settings',
		'choices'        => array(
			'Left Sidebar'  => __('Left Sidebar', 'painting-company'),
			'Right Sidebar' => __('Right Sidebar', 'painting-company'),
		),
	));

	$wp_customize->add_setting('painting_company_related_product_enable',array(
		'default' => true,
		'sanitize_callback'	=> 'painting_company_sanitize_checkbox'
	));
	$wp_customize->add_control('painting_company_related_product_enable',array(
		'type' => 'checkbox',
		'label' => __('Check To Enable Related product','painting-company'),
		'section' => 'painting_company_woocommerce_page_settings',
	));

	$wp_customize->add_setting( 'painting_company_woo_product_img_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'painting_company_sanitize_integer'
    ) );
    $wp_customize->add_control(new Painting_Company_Slider_Custom_Control( $wp_customize, 'painting_company_woo_product_img_border_radius',array(
		'label'	=> esc_html__('Woo Product Img Border Radius','painting-company'),
		'section'=> 'painting_company_woocommerce_page_settings',
		'settings'=>'painting_company_woo_product_img_border_radius',
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 100,
        ),
	)));
    // Add a setting for number of products per row
    $wp_customize->add_setting('painting_company_products_per_row', array(
	    'default'   => '4',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'painting_company_sanitize_integer'  
    ));

   $wp_customize->add_control('painting_company_products_per_row', array(
	   'label'    => __('Products Per Row', 'painting-company'),
	   'section'  => 'painting_company_woocommerce_page_settings',
	   'settings' => 'painting_company_products_per_row',
	   'type'     => 'select',
	   'choices'  => array(
		      '2' => '2',
		'      3' => '3',
		      '4' => '4',
	  ),
   ) );

   // Add a setting for the number of products per page
   $wp_customize->add_setting('painting_company_products_per_page', array(
	'default'   => '9',
	'transport' => 'refresh',
	'sanitize_callback' => 'painting_company_sanitize_integer'
   ));

   $wp_customize->add_control('painting_company_products_per_page', array(
	  'label'    => __('Products Per Page', 'painting-company'),
	  'section'  => 'painting_company_woocommerce_page_settings',
	  'settings' => 'painting_company_products_per_page',
	  'type'     => 'number',
	  'input_attrs' => array(
		 'min'  => 1,
		 'step' => 1,
	 ),
   ));	

   $wp_customize->add_setting('painting_company_product_sale_position',array(
	'default' => 'Left',
	'sanitize_callback' => 'painting_company_sanitize_choices'
	));
	$wp_customize->add_control('painting_company_product_sale_position',array(
		'type' => 'radio',
		'label' => __('Product Sale Position','painting-company'),
		'section' => 'painting_company_woocommerce_page_settings',
		'choices' => array(
			'Left' => __('Left','painting-company'),
			'Right' => __('Right','painting-company'),
		),
	) );   

	//Theme Options
	$wp_customize->add_panel( 'painting_company_panel_area', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'painting-company' ),
	) );

	//Site Layout Section
	$wp_customize->add_section('painting_company_site_layoutsec',array(
		'title'	=> __('Manage Site Layout Section ','painting-company'),
		'description' => __('<p class="sec-title">Manage Site Layout Section</p>','painting-company'),
		'priority'	=> 1,
		'panel' => 'painting_company_panel_area',
	));

	$wp_customize->add_setting('painting_company_box_layout',array(
		'default' => false,
		'sanitize_callback' => 'painting_company_sanitize_checkbox',
	));
	$wp_customize->add_control( 'painting_company_box_layout', array(
	   'section'   => 'painting_company_site_layoutsec',
	   'label'	=> __('Check to Show Box Layout','painting-company'),
	   'type'      => 'checkbox'
 	));

	$wp_customize->add_setting('painting_company_preloader',array(
		'default' => true,
		'sanitize_callback' => 'painting_company_sanitize_checkbox',
	));
	$wp_customize->add_control( 'painting_company_preloader', array(
	   'section'   => 'painting_company_site_layoutsec',
	   'label'	=> __('Check to Show preloader','painting-company'),
	   'type'      => 'checkbox'
 	));

	// Topbar Section
	$wp_customize->add_section('painting_company_topbar_section',array(
	    'title' => __('Manage Topbar Section','painting-company'),
	    'priority'  => null,
	    'panel' => 'painting_company_panel_area',
	));	

	$wp_customize->add_setting('painting_company_banner_topbar_bg_color', array(
        'default'           => '#9051FE',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'painting_company_banner_topbar_bg_color', array(
        'label'    => __('Topbar Background Color', 'painting-company'),
        'section'  => 'painting_company_topbar_section',
    )));

	$wp_customize->add_setting('painting_company_topbar_first_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'painting_company_topbar_first_image',array(
        'label' => __('Topbar Left Image','painting-company'),
        'section' => 'painting_company_topbar_section',
    )));

	$wp_customize->add_setting('painting_company_topbar_second_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'painting_company_topbar_second_image',array(
        'label' => __('Topbar Right Image','painting-company'),
        'section' => 'painting_company_topbar_section',
    )));

	// Banner Section
	$wp_customize->add_section('painting_company_banner_section',array(
	    'title' => __('Manage Banner Section','painting-company'),
	    'priority'  => null,
	    'description'	=> __('<p class="sec-title">Manage Banner Section</p> Select Page from the Dropdowns for banner, Also use the given image dimension (330 x 350).','painting-company'),
	    'panel' => 'painting_company_panel_area',
	));	

	$wp_customize->add_setting('painting_company_banner',array(
		'default' => false,
		'sanitize_callback' => 'painting_company_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'painting_company_banner', array(
	   'settings' => 'painting_company_banner',
	   'section'   => 'painting_company_banner_section',
	   'label'     => __('Check To Enable This Section','painting-company'),
	   'type'      => 'checkbox'
	));

	$wp_customize->add_setting('painting_company_banner_bg_color_first', array(
        'default'           => '#9051FE',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'painting_company_banner_bg_color_first', array(
        'label'    => __('Banner Background Color', 'painting-company'),
        'section'  => 'painting_company_banner_section',
    )));

    $wp_customize->add_setting('painting_company_banner_bg_color_second', array(
        'default'           => '#E9BB00',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'painting_company_banner_bg_color_second', array(
        'label'    => __('Banner Background Color', 'painting-company'),
        'section'  => 'painting_company_banner_section',
    )));

	// Page Dropdown
	$wp_customize->add_setting('painting_company_banner_pageboxes', array(
	    'default'           => '0',
	    'capability'        => 'edit_theme_options',
	    'sanitize_callback' => 'painting_company_sanitize_dropdown_pages',
	));
	$wp_customize->add_control('painting_company_banner_pageboxes', array(
	    'type'     => 'dropdown-pages',
	    'label'    => __('Select Page to display Banner', 'painting-company'),
	    'section'  => 'painting_company_banner_section',
	));

	// Small Title
	$wp_customize->add_setting('painting_company_banner_small_title', array(
	    'default'           => '',
	    'sanitize_callback' => 'sanitize_text_field',
	    'capability'        => 'edit_theme_options',
	));
	$wp_customize->add_control('painting_company_banner_small_title', array(
	    'settings' => 'painting_company_banner_small_title',
	    'section'  => 'painting_company_banner_section',
	    'label'    => __('Add Banner Small Title', 'painting-company'),
	    'type'     => 'text',
	));

	// Button Text
	$wp_customize->add_setting('painting_company_button_text', array(
	    'default'           => 'Explore More',
	    'sanitize_callback' => 'sanitize_text_field',
	    'capability'        => 'edit_theme_options',
	));
	$wp_customize->add_control('painting_company_button_text', array(
	    'settings' => 'painting_company_button_text',
	    'section'  => 'painting_company_banner_section',
	    'label'    => __('Add Banner Button Text', 'painting-company'),
	    'type'     => 'text',
	));

	$wp_customize->add_setting('painting_company_button_icon',array(
        'default'=> 'fa-solid fa-arrow-right-long',
        'sanitize_callback' => 'sanitize_text_field'
    ));
        $wp_customize->add_control('painting_company_button_icon',array(
        'label' => __('Button Icon','painting-company'),
        'description' => __('Fontawesome Icon (e.g., fa-solid fa-arrow-right-long)','painting-company'),
        'section'=> 'painting_company_banner_section',
        'type'=> 'text'
    ));

	// Button Link
	$wp_customize->add_setting('painting_company_button_link_banner', array(
	    'default'           => '',
	    'sanitize_callback' => 'esc_url_raw',
	));
	$wp_customize->add_control('painting_company_button_link_banner', array(
	    'label'    => __('Add Banner Button Link', 'painting-company'),
	    'section'  => 'painting_company_banner_section',
	    'type'     => 'url',
	));

	$wp_customize->add_setting('painting_company_banner_img_bg_color', array(
        'default'           => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'painting_company_banner_img_bg_color', array(
        'label'    => __('Banner Image Background Color', 'painting-company'),
        'section'  => 'painting_company_banner_section',
    )));
    
	// Project Section
	$wp_customize->add_section('painting_company_project_section', array(
	    'title'       => __('Manage Project Section', 'painting-company'),
	    'description' => __('<p class="sec-title">Manage Project Section</p>', 'painting-company'),
	    'priority'    => null,
	    'panel'       => 'painting_company_panel_area',
	));

	$wp_customize->add_setting('painting_company_disabled_project_section', array(
	    'default'           => false,
	    'sanitize_callback' => 'painting_company_sanitize_checkbox',
	    'capability'        => 'edit_theme_options',
	));
	$wp_customize->add_control('painting_company_disabled_project_section', array(
	    'settings' => 'painting_company_disabled_project_section',
	    'section'  => 'painting_company_project_section',
	    'label'    => __('Check To Enable Section', 'painting-company'),
	    'type'     => 'checkbox',
	));

	$wp_customize->add_setting('painting_company_project_title', array(
	    'default'           => '',
	    'sanitize_callback' => 'sanitize_text_field',
	    'capability'        => 'edit_theme_options',
	));
	$wp_customize->add_control('painting_company_project_title', array(
	    'settings' => 'painting_company_project_title',
	    'section'  => 'painting_company_project_section',
	    'label'    => __('Add Project Title', 'painting-company'),
	    'type'     => 'text',
	));

	$wp_customize->add_setting('painting_company_project_text', array(
	    'default'           => '',
	    'sanitize_callback' => 'sanitize_text_field',
	    'capability'        => 'edit_theme_options',
	));
	$wp_customize->add_control('painting_company_project_text', array(
	    'settings' => 'painting_company_project_text',
	    'section'  => 'painting_company_project_section',
	    'label'    => __('Add Project Text', 'painting-company'),
	    'type'     => 'text',
	));

	$painting_company_categories = get_categories();
	$painting_company_cat_post = array();
	$painting_company_cat_post[''] = 'Select';

	foreach ($painting_company_categories as $painting_company_category) {
	    $painting_company_cat_post[$painting_company_category->slug] = $painting_company_category->name;
	}

	$wp_customize->add_setting('painting_company_posts', array(
	    'default'           => '',
	    'sanitize_callback' => 'painting_company_sanitize_choices',
	));

	$wp_customize->add_control('painting_company_posts', array(
	    'type'    => 'select',
	    'choices' => $painting_company_cat_post,
	    'label'   => __('Select Category to display Latest Post', 'painting-company'),
	    'section' => 'painting_company_project_section',
	));

	//Blog post
	$wp_customize->add_section('painting_company_blog_post_settings',array(
        'title' => __('Manage Post Section', 'painting-company'),
        'priority' => null,
        'panel' => 'painting_company_panel_area'
    ) );

    // Add Settings and Controls for Post Layout
	$wp_customize->add_setting('painting_company_sidebar_post_layout',array(
     'default' => 'right',
     'sanitize_callback' => 'painting_company_sanitize_choices'
	));
	$wp_customize->add_control('painting_company_sidebar_post_layout',array(
     'type' => 'radio',
     'label'     => __('Theme Post Sidebar Position', 'painting-company'),
     'description'   => __('This option work for blog page, archive page and search page.', 'painting-company'),
     'section' => 'painting_company_blog_post_settings',
     'choices' => array(
         'full' => __('Full','painting-company'),
         'left' => __('Left','painting-company'),
         'right' => __('Right','painting-company'),
         'three-column' => __('Three Columns','painting-company'),
         'four-column' => __('Four Columns','painting-company'),
         'grid' => __('Grid Layout','painting-company')
     ),
	) );

	$wp_customize->add_setting('painting_company_blog_post_description_option',array(
    	'default'   => 'Excerpt Content', 
        'sanitize_callback' => 'painting_company_sanitize_choices'
	));
	$wp_customize->add_control('painting_company_blog_post_description_option',array(
        'type' => 'radio',
        'label' => __('Post Description Length','painting-company'),
        'section' => 'painting_company_blog_post_settings',
        'choices' => array(
            'No Content' => __('No Content','painting-company'),
            'Excerpt Content' => __('Excerpt Content','painting-company'),
            'Full Content' => __('Full Content','painting-company'),
        ),
	) );
    
	// Footer Section
	$wp_customize->add_section('painting_company_footer', array(
		'title'	=> __('Manage Footer Section','painting-company'),
		'description'	=> __('<p class="sec-title">Manage Footer Section</p>','painting-company'),
		'priority'	=> null,
		'panel' => 'painting_company_panel_area',
	));

	$wp_customize->add_setting('painting_company_footer_widget', array(
	    'default' => true,
	    'sanitize_callback' => 'painting_company_sanitize_checkbox',
	));
	$wp_customize->add_control('painting_company_footer_widget', array(
	    'settings' => 'painting_company_footer_widget',
	    'section'   => 'painting_company_footer',
	    'label'     => __('Check to Enable Footer Widget', 'painting-company'),
	    'type'      => 'checkbox',
	));

	$wp_customize->add_setting('painting_company_footer_bg_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'painting_company_footer_bg_color', array(
        'label'    => __('Footer Background Color', 'painting-company'),
        'section'  => 'painting_company_footer',
    )));

	$wp_customize->add_setting('painting_company_footer_bg_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'painting_company_footer_bg_image',array(
        'label' => __('Footer Background Image','painting-company'),
        'section' => 'painting_company_footer',
    )));

	$wp_customize->add_setting('painting_company_copyright_line',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control( 'painting_company_copyright_line', array(
	   'section' 	=> 'painting_company_footer',
	   'label'	 	=> __('Copyright Line','painting-company'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));

	$wp_customize->add_setting('painting_company_copyright_link',array(
    	'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control( 'painting_company_copyright_link', array(
	   'section' 	=> 'painting_company_footer',
	   'label'	 	=> __('Copyright Link','painting-company'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));

	//  footer coypright color
	$wp_customize->add_setting('painting_company_footercoypright_color',array(
		'default' => '',
		'sanitize_callback' => 'painting_company_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'painting_company_footercoypright_color', array(
	   'settings' => 'painting_company_footercoypright_color',
	   'section'   => 'painting_company_footer',
	   'label' => __('Coypright Color', 'painting-company'),
	   'type'      => 'color'
	));

	//  footer bg color
	$wp_customize->add_setting('painting_company_footerbg_color',array(
		'default' => '',
		'sanitize_callback' => 'painting_company_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'painting_company_footerbg_color', array(
	   'settings' => 'painting_company_footerbg_color',
	   'section'   => 'painting_company_footer',
	   'label' => __('BG Color', 'painting-company'),
	   'type'      => 'color'
	));

	//  footer title color
	$wp_customize->add_setting('painting_company_footertitle_color',array(
		'default' => '',
		'sanitize_callback' => 'painting_company_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'painting_company_footertitle_color', array(
	   'settings' => 'painting_company_footertitle_color',
	   'section'   => 'painting_company_footer',
	   'label' => __('Title Color', 'painting-company'),
	   'type'      => 'color'
	));

	//  footer description color
	$wp_customize->add_setting('painting_company_footerdescription_color',array(
		'default' => '',
		'sanitize_callback' => 'painting_company_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'painting_company_footerdescription_color', array(
	   'settings' => 'painting_company_footerdescription_color',
	   'section'   => 'painting_company_footer',
	   'label' => __('Description Color', 'painting-company'),
	   'type'      => 'color'
	));

	//  footer list color
	$wp_customize->add_setting('painting_company_footerlist_color',array(
		'default' => '',
		'sanitize_callback' => 'painting_company_sanitize_hex_color',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'painting_company_footerlist_color', array(
	   'settings' => 'painting_company_footerlist_color',
	   'section'   => 'painting_company_footer',
	   'label' => __('List Color', 'painting-company'),
	   'type'      => 'color'
	));

	$wp_customize->add_setting('painting_company_scroll_hide', array(
        'default' => true,
        'sanitize_callback' => 'painting_company_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'painting_company_scroll_hide',array(
        'label'          => __( 'Check To Show Scroll To Top', 'painting-company' ),
        'section'        => 'painting_company_footer',
        'settings'       => 'painting_company_scroll_hide',
        'type'           => 'checkbox',
    )));

	$wp_customize->add_setting('painting_company_scroll_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'painting_company_sanitize_choices'
    ));
    $wp_customize->add_control('painting_company_scroll_position',array(
        'type' => 'radio',
        'section' => 'painting_company_footer',
        'label'	 	=> __('Scroll To Top Positions','painting-company'),
        'choices' => array(
            'Right' => __('Right','painting-company'),
            'Left' => __('Left','painting-company'),
            'Center' => __('Center','painting-company')
        ),
    ) );
    
	// Google Fonts
	$wp_customize->add_section( 'painting_company_google_fonts_section', array(
		'title'       => __( 'Google Fonts', 'painting-company' ),
		'priority'    => 24,
	) );

	$font_choices = array(
		'Kaushan Script:' => 'Kaushan Script',
		'Emilys Candy:' => 'Emilys Candy',
		'Poppins:0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900' => 'Poppins',
		'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
		'Open Sans:400italic,700italic,400,700' => 'Open Sans',
		'Oswald:400,700' => 'Oswald',
		'Playfair Display:400,700,400italic' => 'Playfair Display',
		'Montserrat:400,700' => 'Montserrat',
		'Raleway:400,700' => 'Raleway',
		'Droid Sans:400,700' => 'Droid Sans',
		'Lato:400,700,400italic,700italic' => 'Lato',
		'Arvo:400,700,400italic,700italic' => 'Arvo',
		'Lora:400,700,400italic,700italic' => 'Lora',
		'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',
		'Oxygen:400,300,700' => 'Oxygen',
		'PT Serif:400,700' => 'PT Serif',
		'PT Sans:400,700,400italic,700italic' => 'PT Sans',
		'PT Sans Narrow:400,700' => 'PT Sans Narrow',
		'Cabin:400,700,400italic' => 'Cabin',
		'Fjalla One:400' => 'Fjalla One',
		'Francois One:400' => 'Francois One',
		'Josefin Sans:400,300,600,700' => 'Josefin Sans',
		'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
		'Arimo:400,700,400italic,700italic' => 'Arimo',
		'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
		'Bitter:400,700,400italic' => 'Bitter',
		'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',
		'Roboto:400,400italic,700,700italic' => 'Roboto',
		'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
		'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
		'Roboto Slab:400,700' => 'Roboto Slab',
		'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
		'Rokkitt:400' => 'Rokkitt',
	);

	$wp_customize->add_setting( 'painting_company_headings_fonts', array(
		'sanitize_callback' => 'painting_company_sanitize_fonts',
	));
	$wp_customize->add_control( 'painting_company_headings_fonts', array(
		'type' => 'select',
		'description' => __('Select your desired font for the headings.', 'painting-company'),
		'section' => 'painting_company_google_fonts_section',
		'choices' => $font_choices
	));

	$wp_customize->add_setting( 'painting_company_body_fonts', array(
		'sanitize_callback' => 'painting_company_sanitize_fonts'
	));
	$wp_customize->add_control( 'painting_company_body_fonts', array(
		'type' => 'select',
		'description' => __( 'Select your desired font for the body.', 'painting-company' ),
		'section' => 'painting_company_google_fonts_section',
		'choices' => $font_choices
	));
  
}
add_action( 'customize_register', 'painting_company_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function painting_company_customize_preview_js() {
	wp_enqueue_script( 'painting_company_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'painting_company_customize_preview_js' );
