<?php
/**
 * The Template Name: Home Page
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site will use a
 * different template.
 *
 * @package Painting Company
 */

get_header(); ?>

<div id="content" >
    <?php
    $painting_company_banner = get_theme_mod('painting_company_banner', false);
    $painting_company_banner_pageboxes = get_theme_mod('painting_company_banner_pageboxes', false);

    if ($painting_company_banner && $painting_company_banner_pageboxes) { ?>
        <div id="banner-cat" class="pb-md-5">
            <div class="container">
                <div class="banner-page">
                    <?php
                    $painting_company_querymed = new WP_Query(array(
                        'page_id' => esc_attr($painting_company_banner_pageboxes)
                    ));

                    while ($painting_company_querymed->have_posts()) : $painting_company_querymed->the_post(); ?>
                        <div class="row">
                            <div class="col-lg-6 col-md-6 col-12 align-self-center mb-md-0 mb-2 banner-content">
                                <div class="bannerbox">
                                    <?php if (get_theme_mod('painting_company_banner_small_title') != '') { ?>
                                        <p class="banner-smalltitle text-capitalize"><?php echo esc_html(get_theme_mod('painting_company_banner_small_title', 'painting-company')); ?></p>
                                    <?php } ?>
                                    <h1 class="my-3 text-capitalize banner-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h1>
                                    <?php
                                    $painting_company_trimexcerpt = get_the_excerpt();
                                    $painting_company_shortexcerpt = wp_trim_words($painting_company_trimexcerpt, 38);
                                    echo '<p class="banner-content mb-5">' . esc_html($painting_company_shortexcerpt) . '</p>';
                                    ?>
                                    <div class="bannerbtn">
                                        <?php
                                        $painting_company_button_text = get_theme_mod('painting_company_button_text', 'Explore More');
                                        $painting_company_icon = get_theme_mod('painting_company_button_icon', 'fa-solid fa-arrow-right-long');
                                        $painting_company_button_link_banner = esc_url(get_theme_mod('painting_company_button_link_banner', get_permalink()));
                                        if ($painting_company_button_text || !empty($painting_company_button_link_banner)) { ?>
                                            <?php if ($painting_company_button_text != '') { ?>
                                                <a href="<?php echo esc_url($painting_company_button_link_banner); ?>" class="button">
                                                    <?php echo esc_html($painting_company_button_text); ?>
                                                    <span class="screen-reader-text"><?php echo esc_html($painting_company_button_text); ?></span><i class="<?php echo esc_attr($painting_company_icon); ?>"></i>
                                                </a>
                                            <?php } ?>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                            <div class="col-lg-6 col-md-6 col-12 align-self-center text-center banner-right-img">
                                <div class="imagebox">
                                    <?php if (has_post_thumbnail()) {
                                        the_post_thumbnail('full');
                                    } else { ?>
                                        <div class="banner-img-color"></div>
                                    <?php } ?>
                                </div>
                            </div>
                        </div>
                    <?php endwhile;
                    wp_reset_postdata();
                    ?>
                </div>
            </div>
        </div>
    <?php } ?>

    <!-- Project Section -->
    <?php
        $painting_company_hide_project_section = get_theme_mod('painting_company_disabled_project_section', false);
        $painting_company_post_cat = get_theme_mod('painting_company_posts');
        if ($painting_company_hide_project_section){ ?>
        <section id="project-section" class="py-5">
            <div class="container">
                <div class="blog-bx mb-4 text-center">
                    <?php if (get_theme_mod('painting_company_project_title') != "") { ?>
                        <h2 class="project-title mb-1 text-capitalize"><?php echo esc_html(get_theme_mod('painting_company_project_title', 'painting-company')); ?></h2>
                    <?php } ?>
                    <?php if (get_theme_mod('painting_company_project_text') != "") { ?>
                        <p class="project-text mb-1"><?php echo esc_html(get_theme_mod('painting_company_project_text', 'painting-company')); ?></p>
                    <?php } ?>
                </div> 
                <div class="row">
                    <?php
                        $painting_company_page_query = new WP_Query(
                            array(
                                'category_name' => esc_attr($painting_company_post_cat),
                                'posts_per_page' => -1,
                            )
                        );
                        $painting_company_post_counter = 1;
                        while ($painting_company_page_query->have_posts()) : $painting_company_page_query->the_post(); ?>
                            <div class="col-lg-4 col-md-6 col-12 align-self-center mb-3 services px-4">
                                <div class="service-content text-center">
                                    <div class="service-image">
                                        <?php if(has_post_thumbnail()){
                                            the_post_thumbnail('full');
                                            } else{?>
                                            <img src="<?php echo esc_url(get_template_directory_uri()); ?>/images/post-image.png" alt=""/>
                                        <?php } ?>
                                    </div>
                                    <h3 class="post-title pt-2 mb-3"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                    <a class="service-btn" href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html__('View Project', 'painting-company'); ?><i class="fa-solid fa-arrow-right-long"></i></a>
                                </div>
                            </div>
                        <?php $painting_company_post_counter++; ?>
                    <?php endwhile;
                    wp_reset_postdata();
                    ?>
                </div>
            </div>
        </section>
    <?php } ?>
</div>
<?php get_footer(); ?>
